@@ -7,7 +7,7 @@ import { ForeignkeyResolutionError, UpsertionError, ValidationError } from '../e
 import { statkey, updateStat } from '../stats';
 import * as schemas from '../importSchemas';
 import { validateTableRows } from './validateTableRows';
-import { collectTranslationData, bulkUpsertTranslationDefaults } from './translationHandler';
+import { generateTranslationsForData, bulkUpsertTranslationDefaults } from './translationHandler';
 
 function findFieldName(values, fkField) {
   const fkFieldLower = fkField.toLowerCase();
@@ -50,8 +50,6 @@ function loadExisting(Model, values) {
   return loader(Model, values);
 }
 
-
-
 export async function importRows(
   { errors, log, models },
   { rows, sheetName, stats: previousStats = {}, foreignKeySchemata = {}, skipExisting = false },
@@ -237,7 +235,7 @@ export async function importRows(
         await Model.create(values);
         updateStat(stats, statkey(model, sheetName), 'created');
       }
-      const recordTranslationData = collectTranslationData(model, sheetName, values);
+      const recordTranslationData = generateTranslationsForData(model, sheetName, values);
       translationData.push(...recordTranslationData);
     } catch (err) {
       updateStat(stats, statkey(model, sheetName), 'errored');
@@ -245,7 +243,9 @@ export async function importRows(
     }
   }
 
-  await bulkUpsertTranslationDefaults(models, translationData);
+  if (errors.length === 0) {
+    await bulkUpsertTranslationDefaults(models, translationData);
+  }
 
   log.debug('Done with these rows');
   return stats;
